@@ -1,5 +1,5 @@
 package MooseX::Role::Loggable;
-$MooseX::Role::Loggable::VERSION = '0.113';
+$MooseX::Role::Loggable::VERSION = '0.114';
 # ABSTRACT: Extensive, yet simple, logging role using Log::Dispatchouli
 
 use strict;
@@ -11,7 +11,7 @@ use Moo::Role;
 use MooX::Types::MooseLike::Base qw<Bool Str>;
 use Sub::Quote 'quote_sub';
 use Log::Dispatchouli;
-use namespace::sweep;
+use namespace::autoclean;
 
 my %attr_meth_map = (
     'logger_facility' => 'facility',
@@ -216,7 +216,7 @@ MooseX::Role::Loggable - Extensive, yet simple, logging role using Log::Dispatch
 
 =head1 VERSION
 
-version 0.113
+version 0.114
 
 =head1 SYNOPSIS
 
@@ -377,6 +377,14 @@ A L<Log::Dispatchouli> object.
 All methods here are imported from L<Log::Dispatchouli>. You can read its
 documentation to understand them better.
 
+=head2 has_log_file
+
+Determines if C<log_file> was specified.
+
+=head2 has_log_path
+
+Determines if C<log_path> was specified.
+
 =head2 log
 
 Log a message.
@@ -474,7 +482,7 @@ Sawyer X <xsawyerx@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Sawyer X.
+This software is copyright (c) 2017 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
